# RADICAL Campaign Manager

[![Build Status](https://travis-ci.org/radical-project/campaign_manager.svg?branch=devel)](https://travis-ci.org/radical-project/campaign_manager) [![codecov](https://codecov.io/gh/radical-project/campaign_manager/branch/devel/graph/badge.svg)](https://codecov.io/gh/radical-project/campaign_manager)

The `master` branch generally reflects the Campaign Manger release on Pypi, and is
considered stable: it should work 'out of the box'. Please refer to the documentation.

The `devel` branch (and any other branches than master, for that matter)
may not correspond to the published documentation, and specifically may have
dependencies which need to be resolved manually.  Please contact us with an issue
if you need advice on the usage of any non-master branch.


## Installation:

## Usage
